@@ -1,13 +1,11 @@
 package Catalyst::Script::CGI;
 use Moose;
-use namespace::clean -except => [ 'meta' ];
-
-sub _plack_engine_name { 'CGI' }
+BEGIN { $ENV{CATALYST_ENGINE} ||= 'CGI' }
+use namespace::autoclean;
 
 with 'Catalyst::ScriptRole';
 
 __PACKAGE__->meta->make_immutable;
-1;
 
 =head1 NAME
 
@@ -18,16 +16,12 @@ Catalyst::Script::CGI - The CGI Catalyst Script
   myapp_cgi.pl [options]
 
   Options:
-  -?     --help           display this help and exits
+  -h     --help           display this help and exits
 
 =head1 DESCRIPTION
 
 This is a script to run the Catalyst engine specialized for the CGI environment.
 
-=head1 SEE ALSO
-
-L<Catalyst::ScriptRunner>
-
 =head1 AUTHORS
 
 Catalyst Contributors, see Catalyst.pm
